﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say:

    # Defaults for side_image and two_window
    default side_image = None
    default two_window = False

    # Decide if we want to use the one-window or two-window variant.
    if not two_window:

        # The one window variant.
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:
                window:
                    style "say_who_window"

                    text who:
                        id "who"

            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"

    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice:

    window:
        style "menu_window"
        xalign 0.5
        yalign 0.5

        vbox:
            style "menu"
            spacing 2

            for caption, action, chosen in items:

                if action:

                    button:
                        action action
                        style "menu_choice_button"

                        text caption style "menu_choice"

                else:
                    text caption style "menu_caption"
                    
init python:
    style.menu_choice.color = "#ffffff"
    style.menu_choice.size = 40
    style.menu_choice_button.yminimum = 120

    style.menu_choice.hover_color = "#fff"
    style.menu_choice_button.background = Frame("ui/choice_bg_idle.png",28,9)
    style.menu_choice_button.hover_background = Frame("ui/choice_bg_hover.png",28,9)

init -2:
    $ config.narrator_menu = True

    style menu_window is default

    style menu_choice is button_text:
        clear

    style menu_choice_button is button:
        xminimum int(config.screen_width * 0.75)
        xmaximum int(config.screen_width * 0.75)


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input:

    window style "input_window":
        has vbox

        text prompt style "input_prompt"
        input id "input" style "input_text"

    use quick_menu

##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl:

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0

    use quick_menu

##############################################################################
# Main Menu
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu:

    tag menu
    add "ui/mm_1b.jpg"
    add "dynamicLogo"

    add "dynamicLogo2"
    imagemap:
        ground "ui/imageMapBase.png"
        hover "ui/imageMapOverlay.png"
        
        hotspot (500, 568, 267, 96) action Start()
        hotspot (500, 661, 267, 117) action ShowMenu('load')
        hotspot (500, 775, 267, 111) action ShowMenu('preferences')
        hotspot (500, 883, 227, 153) action Quit()#confirm=False)

init -2:

    # Make all the main menu buttons be the same size.
    style mm_button:
        size_group "mm"



##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation:
 # This ensures that any other menu screen is replaced.
    tag menu

    # The background of the game menu.
    window:
        style "gm_root"

screen esc_menu:
     # This ensures that any other menu screen is replaced.
    tag menu

    modal True
    frame xalign 0.5 yalign 0.0 background None:
        imagemap:
            ground "ui/popup_2.jpg"
            idle "ui/popup_1.jpg"
            
            hotspot (413, 187, 229, 104) action Return() 
            hotspot (359, 291, 375, 106) action ShowMenu("save") 
            hotspot (359, 397, 375, 108) action ShowMenu("load") 
            hotspot (39, 721, 273, 87) action ShowMenu("preferences") 
            hotspot (39, 808, 333, 117) action MainMenu()
            hotspot (0, 943, 267, 98)action OpenURL ("http://ithaqualabs.tumblr.com/")
            hotspot (39, 1059, 197, 102) action Quit() #Use action "action Quit(confirm=False)" if you don't want them to confirm to quit. Else use "action ShowMenu("quit")"
        
    
    key "game_menu" action Hide("esc_menu", dissolve)
    frame:
        has vbox
        
        

        



init python:
     config.game_menu_action = [ FileTakeScreenshot(), ShowMenu("esc_menu", transition=dissolve) ]

screen one_button_scr:
    imagebutton:
        align (0.99, 0.98)
        idle "ui/corner1.png"
        hover Animation ("ui/corner2.png", .5, "ui/corner3.png", .5)
        action ShowMenu("esc_menu", transition=dissolve)
    
    imagebutton:
        align (0.55, 0.96)
        idle "ui/ff_1.png"
        hover Animation ("ui/ff_2.png", .5, "ui/ff_1.png", .5)
        action Skip()
    
    imagebutton:
        align (0.40, 0.96)
        idle "ui/rw_1.png"
        hover Animation ("ui/rw_2.png", .5, "ui/rw_1.png", .5)
        action Rollback()
        




init -2:

    # Make all game menu navigation buttons the same size.
    style gm_nav_button:
        size_group "gm_nav"


##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.

screen save:
    
    tag menu

    imagemap:
        ground "ui/saveload1.jpg"
        idle "ui/save1.png"
        hover "ui/save2.png"
        cache False
 
     
        
        hotspot (57,999,87,90) clicked FilePage(1) 
        hotspot (144,999,84,90) clicked FilePage(2) 
        hotspot (228,999,92,90) clicked FilePage(3) 
        hotspot (320,999,78,90) clicked FilePage(4) 

        
        hotspot (111,840,183,88) clicked FilePage("auto") 

        hotspot (506,264,168,87) action FilePageNext()
        
        hotspot (483,1266,219,84) action FilePagePrevious()
        

        
        hotspot (471, 353, 231, 409) clicked FileSave(1):
            use load_save_slot(number=1) 
        hotspot (471, 820, 231, 426) clicked FileSave(2):
            use load_save_slot(number=2) 

        hotspot (57,1171,354,162) action Return() 

 
         
screen load:
   
   tag menu

   imagemap:
        ground "ui/saveload.jpg"
        idle "ui/save1.png"
        hover "ui/save2.png"
        cache False
 
     
        
        hotspot (57,999,87,90) clicked FilePage(1) 
        hotspot (144,999,84,90) clicked FilePage(2) 
        hotspot (228,999,92,90) clicked FilePage(3) 
        hotspot (320,999,78,90) clicked FilePage(4) 

        
        hotspot (111,840,183,88) clicked FilePage("auto") 

        hotspot (506,264,168,87) action FilePageNext()
        
        hotspot (483,1266,219,84) action FilePagePrevious()
        

        
        hotspot (471, 353, 231, 409) clicked FileLoad(1):
            use load_save_slot(number=1) 
        hotspot (471, 820, 231, 426) clicked FileLoad(2):
            use load_save_slot(number=2) 

        hotspot (57,1171,354,162) action Return() 

screen load_save_slot:
    $ file_text = "% 2s. %s\n%s" % (
                        FileSlotName(number, 2),
                        FileTime(number, empty=_("Empty Slot")),
                        FileSaveName(number))


    add FileScreenshot(number) xpos 0 ypos 0
    text file_text xpos 0 ypos 10 size 40 color "#ffffff" outlines [ (2, "#302B54") ] 
    
    key "save_delete" action FileDelete(number)
    
init -2 python:
    
    config.thumbnail_width = 231
    config.thumbnail_height = 426


##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces

screen preferences:
 # This ensures that any other menu screen is replaced.
    tag menu

    imagemap:   
        ground "ui/preferences_2.jpg"
        idle "ui/preferences_6.png"
        hover "ui/preferences_5.png"
        selected_idle "ui/preferences_4.png" 
        selected_hover "ui/preferences_3.png" 
        alpha False
        
        hotspot (423, 488, 345, 53) action Preference("display", "fullscreen")
        hotspot (523, 438, 345, 50) action Preference("display", "window")
        hotspot (448, 663, 309, 58) action Preference("skip", "all") 
        hotspot (435, 604, 322, 59) action Preference("skip", "seen") 
        hotspot (892, 261, 232, 46) action Preference("after choices", "stop") 
        hotspot (893, 220, 237, 42) action Preference("after choices", "skip") 
        
        hotspot (526, 782, 139, 58) action Preference("transitions", "all") 
        hotspot (526, 840, 148, 55) action Preference("transitions", "none") 
                                    
        hotspot (198, 1217, 376, 149) action Return()                            
        bar pos (384, 999) value Preference("text speed") style "pref_slider"
        
        bar pos (0, 999) value Preference("sound volume") style "pref_slider"
        
        bar pos (57, 865) value Preference("music volume") style "pref_slider"
       
        bar pos (198, 1171) value Preference("voice volume") style "pref_slider"

init -2 python:
    style.pref_slider.left_bar = "ui/bar_1.png"
    style.pref_slider.right_bar = "ui/bar_2.png"

    style.pref_slider.xmaximum = 372
    style.pref_slider.ymaximum = 45

    style.pref_slider.thumb = "ui/bar_thing.png"
    style.pref_slider.thumb_offset = 20
    style.pref_slider.thumb_shadow = None


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt

screen yesno_prompt:

    modal True

    window:
        style "gm_root"
        
                
    imagemap:
        ground "ui/quit.jpg"
        idle "ui/yes.png" 
        hover "ui/yes2.png"
        
        hotspot (102, 854, 289, 198) action yes_action
        hotspot (435, 865, 245, 185) action no_action

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05

        has vbox:
            xalign .5
            yalign .5
            spacing 30

        label _(message):
            xalign 0.5


    # Right-click and escape answer "no".
    key "game_menu" action no_action

init -2:
    style yesno_button:
        size_group "yesno"
        

    style yesno_label_text:
        text_align 0.5
        layout "subtitle"
        
init python:
    style.yesno_label.color = "#fff"
    style.yesno_label_text.size = 50


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu:

    # Add an in-game quick menu.
    hbox:
        style_group "quick"

        xalign 1.0
        yalign 1.0

#        textbutton _("Back") action Rollback()
#        textbutton _("Save") action ShowMenu('save')
#        textbutton _("Q.Save") action QuickSave()
#        textbutton _("Q.Load") action QuickLoad()
#        textbutton _("Skip") action Skip()
#        textbutton _("F.Skip") action Skip(fast=True, confirm=True)
#        textbutton _("Auto") action Preference("auto-forward", "toggle")
#        textbutton _("Prefs") action ShowMenu('preferences')

init -2:
    style quick_button:
        is default
        background None
        xpadding 5

    style quick_button_text:
        is default
        size 12
        idle_color "#8888"
        hover_color "#ccc"
        selected_idle_color "#cc08"
        selected_hover_color "#cc0"
        insensitive_color "#4448"

